@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -15,7 +15,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
 
 """In qutebrowser, all keybindings are mapped to commands.
 
@@ -27,7 +27,7 @@ For command arguments, there are also some variables you can use:
 - `{url}` expands to the URL of the current page
 - `{url:pretty}` expands to the URL in decoded format
 - `{url:host}`, `{url:domain}`, `{url:auth}`, `{url:scheme}`, `{url:username}`,
-  `{url:password}`, `{url:host}`, `{url:port}`, `{url:path}` and `{url:query}`
+  `{url:password}`, `{url:port}`, `{url:path}` and `{url:query}`
   expand to the respective parts of the current URL
 - `{title}` expands to the current page's title
 - `{clipboard}` expands to the clipboard contents
