@@ -17,30 +17,28 @@
 # You should have received a copy of the GNU General Public License
 # along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
 
-# pylint: disable=unused-import
-
 """Things needed for end2end testing."""
 
 import re
-import os
-import os.path
+import pathlib
 import sys
 import shutil
 import pstats
 import operator
-import pathlib
 
 import pytest
 from PyQt5.QtCore import PYQT_VERSION, QCoreApplication
 
 pytest.register_assert_rewrite('end2end.fixtures')
 
+# pylint: disable=unused-import
+from end2end.fixtures.notificationserver import notification_server
 from end2end.fixtures.webserver import server, server_per_test, server2, ssl_server
 from end2end.fixtures.quteprocess import (quteproc_process, quteproc,
                                           quteproc_new)
 from end2end.fixtures.testprocess import pytest_runtest_makereport
+# pylint: enable=unused-import
 from qutebrowser.utils import qtutils, utils
-from qutebrowser.browser.webengine import spell
 
 
 def pytest_configure(config):
@@ -56,9 +54,27 @@ def pytest_unconfigure(config):
     """Combine profiles."""
     if config.getoption('--qute-profile-subprocs'):
         stats = pstats.Stats()
-        for fn in os.listdir('prof'):
-            stats.add(os.path.join('prof', fn))
-        stats.dump_stats(os.path.join('prof', 'combined.pstats'))
+        for fn in pathlib.Path('prof').iterdir():
+            stats.add((pathlib.Path('prof') / fn))
+        stats.dump_stats((pathlib.Path('prof') / 'combined.pstats'))
+
+
+def _check_version(op_str, running_version, version_str, as_hex=False):
+    operators = {
+        '==': operator.eq,
+        '!=': operator.ne,
+        '>=': operator.ge,
+        '<=': operator.le,
+        '>': operator.gt,
+        '<': operator.lt,
+    }
+    op = operators[op_str]
+    major, minor, patch = [int(e) for e in version_str.split('.')]
+    if as_hex:
+        version = (major << 16) | (minor << 8) | patch
+    else:
+        version = (major, minor, patch)
+    return op(running_version, version)
 
 
 def _get_version_tag(tag):
@@ -69,7 +85,7 @@ def _get_version_tag(tag):
     casesinto an appropriate @pytest.mark.skip marker, and falls back to
     """
     version_re = re.compile(r"""
-        (?P<package>qt|pyqt)
+        (?P<package>qt|pyqt|pyqtwebengine|python)
         (?P<operator>==|>=|!=|<)
         (?P<version>\d+\.\d+(\.\d+)?)
     """, re.VERBOSE)
@@ -92,18 +108,43 @@ def _get_version_tag(tag):
         }
         return pytest.mark.skipif(do_skip[op], reason='Needs ' + tag)
     elif package == 'pyqt':
-        operators = {
-            '==': operator.eq,
-            '>=': operator.ge,
-            '!=': operator.ne,
-        }
-        op = operators[match.group('operator')]
-        major, minor, patch = [int(e) for e in version.split('.')]
-        hex_version = (major << 16) | (minor << 8) | patch
-        return pytest.mark.skipif(not op(PYQT_VERSION, hex_version),
-                                  reason='Needs ' + tag)
+        return pytest.mark.skipif(
+            not _check_version(
+                op_str=match.group('operator'),
+                running_version=PYQT_VERSION,
+                version_str=version,
+                as_hex=True,
+            ),
+            reason='Needs ' + tag,
+        )
+    elif package == 'pyqtwebengine':
+        try:
+            from PyQt5.QtWebEngine import PYQT_WEBENGINE_VERSION
+        except ImportError:
+            running_version = PYQT_VERSION
+        else:
+            running_version = PYQT_WEBENGINE_VERSION
+        return pytest.mark.skipif(
+            not _check_version(
+                op_str=match.group('operator'),
+                running_version=running_version,
+                version_str=version,
+                as_hex=True,
+            ),
+            reason='Needs ' + tag,
+        )
+    elif package == 'python':
+        running_version = sys.version_info
+        return pytest.mark.skipif(
+            not _check_version(
+                op_str=match.group('operator'),
+                running_version=running_version,
+                version_str=version,
+            ),
+            reason='Needs ' + tag,
+        )
     else:
-        raise ValueError("Invalid package {!r}".format(package))
+        raise utils.Unreachable(package)
 
 
 def _get_backend_tag(tag):
@@ -137,7 +178,7 @@ if not getattr(sys, 'frozen', False):
 
 
 def pytest_collection_modifyitems(config, items):
-    """Apply @qtwebengine_* markers; skip unittests with QUTE_BDD_WEBENGINE."""
+    """Apply @qtwebengine_* markers."""
     # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-75884
     # (note this isn't actually fixed properly before Qt 5.15)
     header_bug_fixed = qtutils.version_check('5.15', compiled=False)
@@ -151,9 +192,9 @@ def pytest_collection_modifyitems(config, items):
         ('qtwebengine_skip', 'Skipped with QtWebEngine', pytest.mark.skipif,
          config.webengine),
         ('qtwebengine_notifications',
-         'Skipped with QtWebEngine < 5.13',
+         'Skipped unless QtWebEngine >= 5.13',
          pytest.mark.skipif,
-         config.webengine and not qtutils.version_check('5.13')),
+         not (config.webengine and qtutils.version_check('5.13'))),
         ('qtwebkit_skip', 'Skipped with QtWebKit', pytest.mark.skipif,
          not config.webengine),
         ('qtwebengine_flaky', 'Flaky with QtWebEngine', pytest.mark.skipif,
@@ -171,7 +212,6 @@ def pytest_collection_modifyitems(config, items):
          'Skipped on Windows',
          pytest.mark.skipif,
          utils.is_windows),
-
     ]
 
     for item in items:
