@@ -18,6 +18,7 @@
 # along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
 
 import os
+import pathlib
 import json
 import time
 import logging
@@ -34,8 +35,8 @@ from qutebrowser.utils import utils
 class TestQtFIFOReader:
 
     @pytest.fixture
-    def reader(self, tmpdir, qapp):
-        fifo_path = str(tmpdir / 'fifo')
+    def reader(self, tmp_path, qapp):
+        fifo_path = str(tmp_path / 'fifo')
         os.mkfifo(fifo_path)  # pylint: disable=no-member,useless-suppression
         reader = userscripts._QtFIFOReader(fifo_path)
         yield reader
@@ -44,7 +45,7 @@ class TestQtFIFOReader:
 
     def test_single_line(self, reader, qtbot):
         """Test QSocketNotifier with a single line of data."""
-        with qtbot.waitSignal(reader.got_line) as blocker:
+        with qtbot.wait_signal(reader.got_line) as blocker:
             with open(reader._filepath, 'w', encoding='utf-8') as f:
                 f.write('foobar\n')
 
@@ -74,8 +75,8 @@ def test_command(qtbot, py_proc, runner):
         with open(os.environ['QUTE_FIFO'], 'w') as f:
             f.write('foo\n')
     """)
-    with qtbot.waitSignal(runner.finished, timeout=10000):
-        with qtbot.waitSignal(runner.got_cmd, timeout=10000) as blocker:
+    with qtbot.wait_signal(runner.finished, timeout=10000):
+        with qtbot.wait_signal(runner.got_cmd, timeout=10000) as blocker:
             runner.prepare_run(cmd, *args)
             runner.store_html('')
             runner.store_text('')
@@ -97,8 +98,8 @@ def test_custom_env(qtbot, monkeypatch, py_proc, runner):
             f.write('\n')
     """)
 
-    with qtbot.waitSignal(runner.finished, timeout=10000):
-        with qtbot.waitSignal(runner.got_cmd, timeout=10000) as blocker:
+    with qtbot.wait_signal(runner.finished, timeout=10000):
+        with qtbot.wait_signal(runner.got_cmd, timeout=10000) as blocker:
             runner.prepare_run(cmd, *args, env=env)
             runner.store_html('')
             runner.store_text('')
@@ -131,8 +132,8 @@ def test_source(qtbot, py_proc, runner):
             f.write('\n')
     """)
 
-    with qtbot.waitSignal(runner.finished, timeout=10000):
-        with qtbot.waitSignal(runner.got_cmd, timeout=10000) as blocker:
+    with qtbot.wait_signal(runner.finished, timeout=10000):
+        with qtbot.wait_signal(runner.got_cmd, timeout=10000) as blocker:
             runner.prepare_run(cmd, *args)
             runner.store_html('This is HTML')
             runner.store_text('This is text')
@@ -142,8 +143,8 @@ def test_source(qtbot, py_proc, runner):
     assert parsed['text'] == 'This is text'
     assert parsed['html'] == 'This is HTML'
 
-    assert not os.path.exists(parsed['text_file'])
-    assert not os.path.exists(parsed['html_file'])
+    assert not pathlib.Path(parsed['text_file']).exists()
+    assert not pathlib.Path(parsed['html_file']).exists()
 
 
 def test_command_with_error(qtbot, py_proc, runner, caplog):
@@ -158,20 +159,20 @@ def test_command_with_error(qtbot, py_proc, runner, caplog):
     """)
 
     with caplog.at_level(logging.ERROR):
-        with qtbot.waitSignal(runner.finished, timeout=10000):
-            with qtbot.waitSignal(runner.got_cmd, timeout=10000) as blocker:
+        with qtbot.wait_signal(runner.finished, timeout=10000):
+            with qtbot.wait_signal(runner.got_cmd, timeout=10000) as blocker:
                 runner.prepare_run(cmd, *args)
                 runner.store_text('Hello World')
                 runner.store_html('')
 
     data = json.loads(blocker.args[0])
-    assert not os.path.exists(data)
+    assert not pathlib.Path(data).exists()
 
 
-def test_killed_command(qtbot, tmpdir, py_proc, runner, caplog):
-    data_file = tmpdir / 'data'
+def test_killed_command(qtbot, tmp_path, py_proc, runner, caplog):
+    data_file = tmp_path / 'data'
     watcher = QFileSystemWatcher()
-    watcher.addPath(str(tmpdir))
+    watcher.addPath(str(tmp_path))
 
     cmd, args = py_proc(r"""
         import os
@@ -195,7 +196,7 @@ def test_killed_command(qtbot, tmpdir, py_proc, runner, caplog):
     """)
     args.append(str(data_file))
 
-    with qtbot.waitSignal(watcher.directoryChanged, timeout=10000):
+    with qtbot.wait_signal(watcher.directoryChanged, timeout=10000):
         runner.prepare_run(cmd, *args)
         runner.store_text('Hello World')
         runner.store_html('')
@@ -203,13 +204,14 @@ def test_killed_command(qtbot, tmpdir, py_proc, runner, caplog):
     # Make sure the PID was written to the file, not just the file created
     time.sleep(0.5)
 
-    data = json.load(data_file)
+    with data_file.open() as f:
+        data = json.load(f)
 
     with caplog.at_level(logging.ERROR):
-        with qtbot.waitSignal(runner.finished):
+        with qtbot.wait_signal(runner.finished):
             os.kill(int(data['pid']), signal.SIGTERM)
 
-    assert not os.path.exists(data['text_file'])
+    assert not pathlib.Path(data['text_file']).exists()
 
 
 def test_temporary_files_failed_cleanup(caplog, qtbot, py_proc, runner):
@@ -220,7 +222,7 @@ def test_temporary_files_failed_cleanup(caplog, qtbot, py_proc, runner):
     """)
 
     with caplog.at_level(logging.ERROR):
-        with qtbot.waitSignal(runner.finished, timeout=10000):
+        with qtbot.wait_signal(runner.finished, timeout=10000):
             runner.prepare_run(cmd, *args)
             runner.store_text('')
             runner.store_html('')
@@ -237,7 +239,7 @@ def test_unicode_error(caplog, qtbot, py_proc, runner):
             f.write(b'\x80')
     """)
     with caplog.at_level(logging.ERROR):
-        with qtbot.waitSignal(runner.finished, timeout=10000):
+        with qtbot.wait_signal(runner.finished, timeout=10000):
             runner.prepare_run(cmd, *args)
             runner.store_text('')
             runner.store_html('')
