@@ -21,12 +21,6 @@
 from qutebrowser.utils import usertypes
 
 
-def test_abstract_certificate_error_wrapper():
-    err = object()
-    wrapper = usertypes.AbstractCertificateErrorWrapper(err)
-    assert wrapper._error is err
-
-
 def test_unset_object_identity():
     assert usertypes.Unset() is not usertypes.Unset()
     assert usertypes.UNSET is usertypes.UNSET
